===
Piu
===

Piu is the command line client for the "even" SSH access granting service.

Installation
============

.. code-block:: bash

    $ sudo pip3 install --upgrade stups-piu

Usage
=====

.. code-block:: bash

    $ piu myuser@myhost my-reason

